==> pipewire-docs-1%3A0.3.69-2-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"alloc_8h.html",
"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
"group__pw__global.html#gab6796dae933803798be1658f4020315c",
"group__pw__keys.html#gaa039c0a911742213e239311ec73b623b",
"group__pw__node.html#ga3c668f349296e6fcbf3b294b92274f1f",
"group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219",
"group__pwtest.html#ga135297caa69f5e14b2b20148850d080b",
"group__spa__cpu.html#gad4c6b81675ec1a16c23239041970f099",
"group__spa__json.html#ga6d871debd28993273c3cbb1b0f7fce64",
"group__spa__names.html#gadc887e81536271d1538500da0fb6be1f",
"group__spa__param.html#ga49c3cb2109aab971f92dfe13bde3759b",
"group__spa__param.html#gga3338e5f0867a0e073d8dcfd309fe8850a682778cce4e3c92fa38ba77e8f838246",
"group__spa__param.html#gga9c37ad62772233835d6bf5083a9e4613a3c01bfb4218e827d2d2f21385d71798e",
"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43eaa9b46794cf9585c21b7880d238ce2355",
"group__spa__pod.html#gab23072b3f0f817478e011658b3504161",
"group__spa__utils__defs.html#ga01ba22304e834c86556e645614f65d84",
"page_module_roc_sink.html",
"structpw__client__events.html#a58af5a46ef2875bf85f2683ed522d254",
"structpw__impl__link__events.html",
"structpw__registry__events.html#a04c4f7cbbf5dcc0c54887862887dbc97",
"structspa__device__events.html#a0b9ba211d7f484c7df9ac269d5b49af3",
"structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913",
"structspa__strbuf.html#ac82fdbc33669185a77140a3faf908a0c"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> pipewire-docs-1%3A0.3.70-1-aarch64.pkg.tar.xz: usr/share/doc/pipewire/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PipeWire", "index.html", [
    [ "Components", "index.html#autotoc_md0", null ],
    [ "API Documentation", "index.html#autotoc_md1", null ],
    [ "More Documentation", "index.html#autotoc_md2", null ],
    [ "Resources", "index.html#autotoc_md3", null ],
    [ "Overview", "page_overview.html", [
      [ "Motivation", "page_overview.html#autotoc_md4", null ]
    ] ],
    [ "PipeWire Design", "page_pipewire.html", "page_pipewire" ],
    [ "PipeWire Modules", "page_pipewire_modules.html", "page_pipewire_modules" ],
    [ "Tutorial", "page_tutorial.html", "page_tutorial" ],
    [ "PipeWire API", "page_api.html", "page_api" ],
    [ "SPA (Simple Plugin API)", "page_spa.html", "page_spa" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Globals", "globals.html", [
      [ "All", "globals.html", "globals_dup" ],
      [ "Functions", "globals_func.html", "globals_func" ],
      [ "Variables", "globals_vars.html", null ],
      [ "Typedefs", "globals_type.html", null ],
      [ "Enumerations", "globals_enum.html", null ],
      [ "Enumerator", "globals_eval.html", "globals_eval" ],
      [ "Macros", "globals_defs.html", "globals_defs" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"alloc_8h.html",
"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0",
"group__pw__global.html#ga7c5ab037320ab252af6eb6eb1b85b0b9",
"group__pw__keys.html#ga94975808271e28be225a6fd6d7957762",
"group__pw__node.html#ga13f0cb22b45e8f81e709b84ff3b1fde7",
"group__pw__session__manager.html#ga0b0bc42cc601ef5c82090d463694b5c2",
"group__pw__work__queue.html#ga56673e78071d8a9eb28805331c8b2245",
"group__spa__cpu.html#gaabed68d3b3d4db276c57891df69fbc93",
"group__spa__json.html#ga4dbbb0d8d43216c23d20b08be1650437",
"group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f",
"group__spa__param.html#ga4077adc9cb334bd78d561f96c04eebbc",
"group__spa__param.html#gga24bd9414a34ba30e9c0f0ad99b86e427ad6c7dc4e62838af48f2451c84e53d7fa",
"group__spa__param.html#gga99c6341a3416bdaacc42f77fc4869821a4ba324c410f312d2561dffb47e9af99b",
"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea91b3097e817b6334a4e50614fa64ede5",
"group__spa__pod.html#gaa5ae3c08bb5f3e90e5b0688c5668e002",
"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635af25926b5d489ddd2acb63ea263c78e92",
"page_module_metadata.html",
"structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1",
"structpw__impl__factory__events.html",
"structpw__proxy__events.html",
"structspa__debug__log__ctx.html#a283294f711d9752bb65c8c09e5a06724",
"structspa__loop__methods.html#ae7dc5184539a2425309dee69d2867dcf",
"structspa__source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
